import styles from "./styles.module.css";
import Search from "../search";
import Icons from "../icons";
import { useTheme } from "@/app/context/index";
import Link from "next/link";

function Header({ name, onThemeChange, onSearch, onClose }) {
  const { theme, toggleTheme } = useTheme();

  const handleTheme = () => {
    toggleTheme();
    onThemeChange(theme);
  };
  const handleSearch = (value) => {
    onSearch(value);
  };
  const handleClose = () => {
    onClose("");
  };
  return (
    <header className={styles.header}>
      <div className={styles.container}>
        <nav className={styles.navbar}>
          <Link className={styles["navbar-brand"]} href="/">
            <Icons name="newspaper" size="medium" classes="newspaper-icon" />
            <h2>{name}</h2>
          </Link>

          <div className={styles.search}>
            <Search onSearch={handleSearch} onClose={handleClose} />
          </div>

          <div onClick={handleTheme} className={styles.themelight}>
            <Icons name={theme == "light" ? "moon" : "sun"} size="medium" />
            <span className={styles.mobilemenu}>
              <Icons name="hamburger" size="medium" classes="menu-icon" />
            </span>
          </div>
        </nav>
      </div>
    </header>
  );
}

export default Header;
