import Image from "next/image";
import styles from "./styles.module.css";
import ReactMarkdown from "react-markdown";
import remarkGfm from "remark-gfm";
import PropTypes from "prop-types";

function SingleBlog({
  title,
  publishedDate,
  authorName,
  category,
  readingTime,
  images,
  categories,
  markdown,
}) {
  return (
    <>
      <div className={styles["head-container"]}>
        <div className={styles.headtitle}>
          <h1 className={styles.title}>{title}</h1>
        </div>
        <div className={styles["blog-list"]}>
          <ul>
            <li>
              Posted on
              <span className={styles["list-bold"]}>{publishedDate}</span>
            </li>
            <li>
              By&nbsp;
              <a href="#" className={styles["list-bold"]}>
                {authorName}
              </a>
            </li>
            <li>
              Published in&nbsp;
              <a href="#" className={styles["list-bold"]}>
                {category}
              </a>
            </li>
            <li>
              <a href="#" className={styles["list-bold"]}>
                {readingTime}
              </a>
            </li>
          </ul>
        </div>
      </div>
      <div className={styles["blog-container"]}>
        <div className={styles.blogimage}>
          <Image className={styles.img} src={images.url} alt={title} />
        </div>
        <div className={styles["blog-content"]}>
          <ReactMarkdown remarkPlugins={[remarkGfm]}>{markdown}</ReactMarkdown>
          <div className={styles.tag}>
            <h3>Tags:</h3>
            {categories.map((e, i) => (
              <p key={i}>{e}</p>
            ))}
          </div>
        </div>
      </div>
    </>
  );
}

SingleBlog.propTypes = {
  title: PropTypes.string,
  publishedDate: PropTypes.string,
  authorName: PropTypes.string,
  category: PropTypes.string,
  readingTime: PropTypes.string,
  categories: PropTypes.array,
  image: PropTypes.shape({
    url: PropTypes.string,
  }),
};
export default SingleBlog;
